#!/usr/bin/perl

use FDN::Common::Config;
use FDN::Common::Modules;
use FDN::Adsl::Basic;
use FDN::Adsl::Ag;

my @adhs = tous_clients_actifs();

if ( ! @ARGV || $ARGV[0] eq '-h' ) {
	print STDERR "Syntax: $0 [--force] annee\n";
	print STDERR "--force : refait les PDF qui existent deja\n";
	print STDERR "annee : annee sur 4 chiffres\n";
	exit 1;
}

my $force = 0;
my $annee = shift @ARGV;
if ( $annee eq '--force' ) {
	$force = 1;
	$annee = shift @ARGV;
}
if ( $annee !~ /^20\d\d$/ ) {
	die "Je veux une annee en parametre";
}

conduse('FDN::TeX::TeX');
if ( ! set_tex_config('adsl/tex-tmp.cfg') ) {
	die "Horribly";
}
$FDN::TeX::TeX::debug=0;

my $date = Config_Key('adsl/adhs/ag.cfg','ag-'.$annee,'date');
if ( ! defined $date ) {
	die "Dans le fichier adsl/adsh/ag.cfg, pour la section [ag-$annee], je veux une clef 'date'...";
}

# Les fichiers PDF sont stocks l:
my $base = Config_Key('adsl/global.cfg','dirs','stockpdf');
my $doc = 'ag'.$annee.'.pdf';

my $count = 0;

for my $adh ( @adhs ) {
	if ( ! droit_de_vote($adh,$date,'present') ) {
		print $adh->{'CLIENT_NUMADH'}.'/'.$adh->{'CLIENT_NOM'}.": Pas adhrent  la date de l'AG, pas de convocation pour lui.elle.\n";
		next;
	}


	my $adr = adresse_par_id($adh->{'ADRESSE_ID'});
	my $acc = adhaccess_par_client_id($adh->{'CLIENT_ID'});
	if ( $adh->{'CLIENT_NUMADH'} <= 0 ) {
		print $adh->{'CLIENT_NUMADH'}.'/'.$adh->{'CLIENT_NOM'}.": Pas de numero d'adherent.e, je zappe.\n";
		next;
	}

	print "On fait $adh->{'CLIENT_NUMADH'}, $adh->{'CLIENT_NOM'}... ";
	$adr->{'ADRESSE_ADR'} =~ s/\s*[\n\r]+/\n/sg;
	my $hash = {
		'NOM' => tex_encode($adr->{'ADRESSE_NOM'}),
		'ADRESSE' => tex_encode($adr->{'ADRESSE_ADR'}),
		'CP' => $adr->{'ADRESSE_CP'},
		'VILLE' => tex_encode($adr->{'ADRESSE_VILLE'}),
		'numadh' => $adh->{'CLIENT_NUMADH'},
		'login' => $acc->{'ADHACCESS_LOGIN'},
		'passwd' => tex_encode($acc->{'ADHACCESS_PASSWD'})
	};

	my $dir = 'adhacc-'.$adh->{'CLIENT_ID'};
	if ( ! -d $base.'/'.$dir ) {
		mkdir "$base/$dir";
	}

	my $pdf = $base.'/'.$dir.'/'.$doc;
	if ( -f $pdf && ! $force ) {
		print "Deja fait\n";
		next;
	}

	my $Hash = { 'enveloppes' => [ $hash ] };
	my $file = make_pdf_file('ag'.$annee, 'ag'.$annee, $Hash);
	if ( ! defined $file ) {
		die "Echec de la compilation du fichier\n";
		next;
	}
	
	my $dir = 'adhacc-'.$adh->{'CLIENT_ID'};
	if ( ! -d $base.'/'.$dir ) {
		mkdir "$base/$dir";
	}
	if ( ! -d $base.'/'.$dir ) {
		print "Le repertoire $base/$dir pour l'adherent.e devrait sans doute deja exister... Echec.\n";
		next;
	}
	my $pdf = $base.'/'.$dir.'/'.$doc;
	`cp $file $pdf`;
	if ( ! -f $pdf ) {
		print "Echec de la copie du fichier\n";
		next;
	}
	print "OK\n";
	$count++;
}

print "On a produit et range $count convocations pour l'annee $annee.\n";


