#!/usr/bin/perl

use strict;
use FDN::Common::Config;
use FDN::TeX::TeX;

use FDN::Adsl::Ag;
use FDN::Adsl::Basic;

my $annee = shift(@ARGV);
if ( $annee !~ /^20\d\d$/ ) {
	print STDERR "Syntax: $0 <annee>\n";
	print STDERR "Fait le fichier PDF avec la liste des procurations\n" ;
	exit(1);
}

my $cfg = Config_Section('adsl/adhs/ag.cfg', 'ag-'.$annee);

if ( ! $cfg || $cfg->{'status'} =~ /^(new|old)/ ) {
	print STDERR "Annee inconnue ou mal configuree (on ne liste pas les procus des annees new, ou old).\n";
	exit(1);
}
my $prefix = '';
if ( $cfg->{'status'} ne 'close' ) {
	$prefix = 'SPECIMEN TEMPORAIRE ';
}

my $date = $cfg->{'date'};

my $total = 0;
my $procus = {};
my $convs = [ tous_convocation() ];
for my $conv ( @$convs ) {
	my $cid = $conv->{'CLIENT_ID'};
	my ( $forme, $pres, $proc ) = split_convocation($cid, $annee);
	next if ! $proc;
	my $numadh = numadh_convocation_procuration($cid, $annee);
	if ( $numadh !~ /^\d+$/ ) {
		# Pas de procuration, suivant
		next;
	}

	my $client = client_par_id($cid);
	if ( ! defined $procus->{$numadh} ) {
		$procus->{$numadh} = {};
		my $tmp = client_par_numadh($numadh);
		$procus->{$numadh}->{'numadh'} = $numadh;
		$procus->{$numadh}->{'count'} = 0;
		$procus->{$numadh}->{'name'} = $prefix.tex_encode($tmp->{'CLIENT_NOM'});
		$procus->{$numadh}->{'list'} = [];
	}
	push @{$procus->{$numadh}->{'list'}}, {
		'numadh' => $client->{'CLIENT_NUMADH'},
		'name' => tex_encode($client->{'CLIENT_NOM'})
	};
	$procus->{$numadh}->{'count'}++;
	$total++;
}

for my $numadh ( keys %$procus ) {
	$procus->{$numadh}->{'list'} = [ sort { $a->{'numadh'} <=> $b->{'numadh'} } @{$procus->{$numadh}->{'list'}} ];
}

my $count = 0;
if ( $cfg->{'@procu'} ) {
	for my $manuelle ( @{$cfg->{'@procu'}} ) {
		next if $manuelle !~ /(\d+),(.*)$/;
		my ( $num, $nom ) = ( $1, $2 );
		my $client = client_par_numadh($num);
		if ( ! $client ) {
			# Procuration invalide
			next;
		}
		$procus->{'manu-'.$count} = {
			'numadh' => 'Ext',
			'count' => 1,
			'name' => tex_encode($nom),
			'list' => [ {
				'numadh' => $client->{'CLIENT_NUMADH'},
				'name' => tex_encode($client->{'CLIENT_NOM'})
			} ]
		};
		$count++;
		$total++;
	}
}

set_tex_config('adsl/tex-tmp.cfg');
my $Hash = { 'procus' => [ sort { $a->{'numadh'} <=> $b->{'numadh'} } values %$procus ] };
my $file = make_pdf_file('procus','procus',$Hash);

if ( defined $file ) {
        print "Fichier produit: $file\n";
	print "Au total $total procurations dont $count faites a la main\n";
} else {
        print "Echec de la compilation\n";
}

